
# USB Protocol Library for Python

`usb-descriptors` is a library that collects common data-processing code for USB tasks;
and is meant to support a variety of projects, including USB stacks, analyzers, and
other tools that work with USB data.
Primary use is as a tool to easily construct USB descriptors with python.

The library is currently an early work-in-progress; this documentation will be updated
when the project is more mature.

# notable differences to `usb-protocol`
The USB Audio/MIDI class implementation which originally was contributed to `usb-protocol`
is broken there and is fixed in this project.